Web   ·   Wiki   ·   Activities   ·   Blog   ·   Lists   ·   Chat   ·   Meeting   ·   Bugs   ·   Git   ·   Translate   ·   Archive   ·   People   ·   Donate
summaryrefslogtreecommitdiffstats
path: root/PurePyGTKLauncher.py
diff options
context:
space:
mode:
Diffstat (limited to 'PurePyGTKLauncher.py')
-rwxr-xr-xPurePyGTKLauncher.py32
1 files changed, 15 insertions, 17 deletions
diff --git a/PurePyGTKLauncher.py b/PurePyGTKLauncher.py
index b3b69d3..0304288 100755
--- a/PurePyGTKLauncher.py
+++ b/PurePyGTKLauncher.py
@@ -1,27 +1,25 @@
# PurePyGTKLauncher.py Launch the application in non-Sugar environments
#
-# Copyright (C) 2011 Laurent BERNABE
+#This file is part of LearningWriting.
#
# This program is free software; you can redistribute it
# and/or modify it under the terms of the GNU General
# Public License as published by the Free Software
# Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will
# be useful, but WITHOUT ANY WARRANTY; without even
# the implied warranty of MERCHANTABILITY or FITNESS FOR
# A PARTICULAR PURPOSE. See the GNU General Public
# License for more details.
#
-# You should have received a copy of the GNU General
-# Public License along with this program; if not, write
-# to the Free Software Foundation, Inc., 51 Franklin
-# St, Fifth Floor, Boston, MA 02110-1301 USA
+#You should have received a copy of the GNU General Public License
+#along with LearningWriting. If not, see <http://www.gnu.org/licenses/>.
import gtk
-from TheWindow import TheWindow
+from com.gmail.bernabe.laurent.sugar_olpc.learning_writing.TheWindow import TheWindow
if __name__ == '__main__':
TheWindow()
- gtk.main() \ No newline at end of file
+ gtk.main()
+
+ #TODO there is no menu bar : create it. \ No newline at end of file
@@ -1,27 +1,25 @@
#
-# This program is free software; you can redistribute it
-# and/or modify it under the terms of the GNU General
-# Public License as published by the Free Software
-# Foundation; either version 2 of the License, or
-# (at your option) any later version.
+#LearningWriting is free software: you can redistribute it and/or modify
+#it under the terms of the GNU General Public License as published by
+#the Free Software Foundation, either version 3 of the License, or
+#(at your option) any later version.
#
@@ -1,27 +1,25 @@
#
-# This program is distributed in the hope that it will
-# be useful, but WITHOUT ANY WARRANTY; without even
-# the implied warranty of MERCHANTABILITY or FITNESS FOR
-# A PARTICULAR PURPOSE. See the GNU General Public
-# License for more details.
+#LearningWriting is distributed in the hope that it will be useful,
+#but WITHOUT ANY WARRANTY; without even the implied warranty of
+#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+#GNU General Public License for more details.
#